Struct pallet_transaction_payment::ChargeTransactionPayment [−][src]
pub struct ChargeTransactionPayment<T: Config>(_);Expand description
Require the transactor pay for themselves and maybe include a tip to gain additional priority in the queue.
Transaction Validity
This extension sets the priority field of TransactionValidity depending on the amount
of tip being paid per weight unit.
Operational transactions will receive an additional priority bump, so that they are normally considered before regular transactions.
Implementations
impl<T: Config> ChargeTransactionPayment<T> where
T::Call: Dispatchable<Info = DispatchInfo, PostInfo = PostDispatchInfo>,
<<T as Config>::OnChargeTransaction as OnChargeTransaction<T>>::Balance: Send + Sync + FixedPointOperand,
impl<T: Config> ChargeTransactionPayment<T> where
T::Call: Dispatchable<Info = DispatchInfo, PostInfo = PostDispatchInfo>,
<<T as Config>::OnChargeTransaction as OnChargeTransaction<T>>::Balance: Send + Sync + FixedPointOperand,
pub fn from(
fee: <<T as Config>::OnChargeTransaction as OnChargeTransaction<T>>::Balance
) -> Self
pub fn from(
fee: <<T as Config>::OnChargeTransaction as OnChargeTransaction<T>>::Balance
) -> Self
utility constructor. Used only in client/factory code.
Returns the tip as being choosen by the transaction sender.
pub fn get_priority(
info: &DispatchInfoOf<T::Call>,
len: usize,
tip: <<T as Config>::OnChargeTransaction as OnChargeTransaction<T>>::Balance,
final_fee: <<T as Config>::OnChargeTransaction as OnChargeTransaction<T>>::Balance
) -> TransactionPriority
pub fn get_priority(
info: &DispatchInfoOf<T::Call>,
len: usize,
tip: <<T as Config>::OnChargeTransaction as OnChargeTransaction<T>>::Balance,
final_fee: <<T as Config>::OnChargeTransaction as OnChargeTransaction<T>>::Balance
) -> TransactionPriority
Get an appropriate priority for a transaction with the given DispatchInfo, encoded length
and user-included tip.
The priority is based on the amount of tip the user is willing to pay per unit of either
weight or length, depending which one is more limitting. For Operational extrinsics
we add a “virtual tip” to the calculations.
The formula should simply be tip / bounded_{weight|length}, but since we are using
integer division, we have no guarantees it’s going to give results in any reasonable
range (might simply end up being zero). Hence we use a scaling factor:
tip * (max_block_{weight|length} / bounded_{weight|length}), since given current
state of-the-art blockchains, number of per-block transactions is expected to be in a
range reasonable enough to not saturate the Balance type while multiplying by the tip.